SLING-11348 Support rereading of content
diff --git a/pom.xml b/pom.xml
index 4ac9607..3494923 100644
--- a/pom.xml
+++ b/pom.xml
@@ -29,7 +29,7 @@
   </parent>
 
   <artifactId>org.apache.sling.commons.content.analyzing</artifactId>
-  <version>1.0.1-SNAPSHOT</version>
+  <version>2.0.0-SNAPSHOT</version>
 
   <name>Apache Sling Commons Content Analyzing</name>
   <description>Apache Sling Commons Content Analyzing</description>
diff --git a/src/main/java/org/apache/sling/commons/content/analyzing/package-info.java b/src/main/java/org/apache/sling/commons/content/analyzing/package-info.java
index 5af87b0..0330a26 100644
--- a/src/main/java/org/apache/sling/commons/content/analyzing/package-info.java
+++ b/src/main/java/org/apache/sling/commons/content/analyzing/package-info.java
@@ -20,7 +20,7 @@
 /**
  * Provides the Apache Sling Commons Content Analyzing API.
  */
-@Version("1.0.0")
+@Version("2.0.0")
 package org.apache.sling.commons.content.analyzing;
 
 import org.osgi.annotation.versioning.Version;
diff --git a/src/main/java/org/apache/sling/commons/content/analyzing/ContentAnalyzer.java b/src/main/java/org/apache/sling/commons/content/analyzing/ContentAnalyzer.java
index c169c8d..bec9ce8 100644
--- a/src/main/java/org/apache/sling/commons/content/analyzing/ContentAnalyzer.java
+++ b/src/main/java/org/apache/sling/commons/content/analyzing/ContentAnalyzer.java
@@ -21,6 +21,7 @@
 import java.io.InputStream;
 import java.util.Map;
 import java.util.concurrent.CompletableFuture;
+import java.util.function.Supplier;
 
 import org.jetbrains.annotations.NotNull;
 import org.jetbrains.annotations.Nullable;
@@ -35,11 +36,11 @@
     /**
      * Analyzes the given content.
      *
      * @param input      the stream from which the content is read for analyzing
      * @param parameters the parameters for the analyzing operation
      * @param report     the report to which the findings of the analyzing operation are added
      * @return {@link java.util.concurrent.CompletableFuture} for signaling completion
      */
-    public abstract @NotNull CompletableFuture<Void> analyze(@NotNull final InputStream input, @Nullable final Map<String, Object> parameters, @NotNull final Map<String, Object> report);
+    public abstract @NotNull CompletableFuture<Void> analyze(@NotNull final Supplier<InputStream> input, @Nullable final Map<String, Object> parameters, @NotNull final Map<String, Object> report);
 
 }
@@ -35,11 +36,11 @@
      * Analyzes the given content.
      *
-     * @param input      the stream from which the content is read for analyzing
+     * @param input      the supplier of the stream from which the content is read for analyzing
      * @param parameters the parameters for the analyzing operation
      * @param report     the report to which the findings of the analyzing operation are added